==> sdd.ebfapi.client-0.1.22-sources.jar: ar/com/sdd/ebfapi/client/model/DocumentReasonTypeEbfApi.java <==
package ar.com.sdd.ebfapi.client.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import java.io.Serializable;
import java.math.BigDecimal;

@JsonIgnoreProperties(ignoreUnknown = true)
public class DocumentReasonTypeEbfApi implements Serializable {

    private String id;
    private Long owner;
    private String type;
    private String name;
    private String description;
    private Boolean visible;
    private Boolean enable;
    private Boolean obligatoryComment;
    private String dedRetMessage;
    private Long intCode;
    private BigDecimal rpgMaxPercentage;
    private Boolean retObligatoryRefNumber;
    private String hasDetail;
    private String externalReference;
    private Boolean deferredDate;
    private String subtype;
    private String reference;
    private Boolean viewSuc;
    private Boolean reqIssueDate;
    private Boolean reqCurrencyRate;
    private Boolean reqIssuerBank;
    private String optionCodes;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Long getOwner() {
        return owner;
    }

    public void setOwner(Long owner) {
        this.owner = owner;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Boolean getVisible() {
        return visible;
    }

    public void setVisible(Boolean visible) {
        this.visible = visible;
    }

    public Boolean getEnable() {
        return enable;
    }

    public void setEnable(Boolean enable) {
        this.enable = enable;
    }

    public Boolean getObligatoryComment() {
        return obligatoryComment;
    }

    public void setObligatoryComment(Boolean obligatoryComment) {
        this.obligatoryComment = obligatoryComment;
    }

    public String getDedRetMessage() {
        return dedRetMessage;
    }

    public void setDedRetMessage(String dedRetMessage) {
        this.dedRetMessage = dedRetMessage;
    }

    public Long getIntCode() {
        return intCode;
    }

    public void setIntCode(Long intCode) {
        this.intCode = intCode;
    }

    public BigDecimal getRpgMaxPercentage() {
        return rpgMaxPercentage;
    }

    public void setRpgMaxPercentage(BigDecimal rpgMaxPercentage) {
        this.rpgMaxPercentage = rpgMaxPercentage;
    }

    public Boolean getRetObligatoryRefNumber() {
        return retObligatoryRefNumber;
    }

    public void setRetObligatoryRefNumber(Boolean retObligatoryRefNumber) {
        this.retObligatoryRefNumber = retObligatoryRefNumber;
    }

    public String getHasDetail() {
        return hasDetail;
    }

    public void setHasDetail(String hasDetail) {
        this.hasDetail = hasDetail;
    }

    public String getExternalReference() {
        return externalReference;
    }

    public void setExternalReference(String externalReference) {
        this.externalReference = externalReference;
    }

    public Boolean getDeferredDate() {
        return deferredDate;
    }

    public void setDeferredDate(Boolean deferredDate) {
        this.deferredDate = deferredDate;
    }

    public String getSubtype() {
        return subtype;
    }

    public void setSubtype(String subtype) {
        this.subtype = subtype;
    }

    public String getReference() {
        return reference;
    }

    public void setReference(String reference) {
        this.reference = reference;
    }

    public Boolean getViewSuc() {
        return viewSuc;
    }

    public void setViewSuc(Boolean viewSuc) {
        this.viewSuc = viewSuc;
    }

    public Boolean getReqIssueDate() {
        return reqIssueDate;
    }

    public void setReqIssueDate(Boolean reqIssueDate) {
        this.reqIssueDate = reqIssueDate;
    }

    public Boolean getReqCurrencyRate() {
        return reqCurrencyRate;
    }

    public void setReqCurrencyRate(Boolean reqCurrencyRate) {
        this.reqCurrencyRate = reqCurrencyRate;
    }

    public Boolean getReqIssuerBank() {
        return reqIssuerBank;
    }

    public void setReqIssuerBank(Boolean reqIssuerBank) {
        this.reqIssuerBank = reqIssuerBank;
    }

    public String getOptionCodes() {
        return optionCodes;
    }

    public void setOptionCodes(String optionCodes) {
        this.optionCodes = optionCodes;
    }

    @Override
    public String toString() {
        return "DocumentReasonTypeEbfApi ["
                + ((id != null) ? "id=" + id + ", " : "")
                + ((owner != null) ? "owner=" + owner + ", " : "")
                + ((type != null) ? "type=" + type + ", " : "")
                + ((name != null) ? "name=" + name + ", " : "")
                + ((description != null) ? "description=" + description + ", " : "")
                + ((visible != null) ? "visible=" + visible + ", " : "")
                + ((enable != null) ? "enable=" + enable + ", " : "")
                + ((obligatoryComment != null) ? "obligatoryComment=" + obligatoryComment + ", " : "")
                + ((dedRetMessage != null) ? "dedRetMessage=" + dedRetMessage + ", " : "")
                + ((intCode != null) ? "intCode=" + intCode + ", " : "")
                + ((rpgMaxPercentage != null) ? "rpgMaxPercentage=" + rpgMaxPercentage + ", " : "")
                + ((retObligatoryRefNumber != null) ? "retObligatoryRefNumber=" + retObligatoryRefNumber + ", " : "")
                + ((hasDetail != null) ? "hasDetail=" + hasDetail + ", " : "")
                + ((externalReference != null) ? "externalReference=" + externalReference + ", " : "")
                + ((deferredDate != null) ? "deferredDate=" + deferredDate + ", " : "")
                + ((subtype != null) ? "subtype=" + subtype + ", " : "")
                + ((reference != null) ? "reference=" + reference + ", " : "")
                + ((viewSuc != null) ? "viewSuc=" + viewSuc + ", " : "")
                + ((reqIssueDate != null) ? "reqIssueDate=" + reqIssueDate + ", " : "")
                + ((reqCurrencyRate != null) ? "reqCurrencyRate=" + reqCurrencyRate + ", " : "")
                + ((reqIssuerBank != null) ? "reqIssuerBank=" + reqIssuerBank + ", " : "")
                + ((optionCodes != null) ? "optionCodes=" + optionCodes : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        DocumentReasonTypeEbfApi that = (DocumentReasonTypeEbfApi) o;

        if (id != null ? !id.equals(that.id) : that.id != null) return false;
        if (owner != null ? !owner.equals(that.owner) : that.owner != null) return false;
        if (type != null ? !type.equals(that.type) : that.type != null) return false;
        if (name != null ? !name.equals(that.name) : that.name != null) return false;
        if (description != null ? !description.equals(that.description) : that.description != null) return false;
        if (visible != null ? !visible.equals(that.visible) : that.visible != null) return false;
        if (enable != null ? !enable.equals(that.enable) : that.enable != null) return false;
        if (obligatoryComment != null ? !obligatoryComment.equals(that.obligatoryComment) : that.obligatoryComment != null) return false;
        if (dedRetMessage != null ? !dedRetMessage.equals(that.dedRetMessage) : that.dedRetMessage != null) return false;
        if (intCode != null ? !intCode.equals(that.intCode) : that.intCode != null) return false;
        if (rpgMaxPercentage != null ? !rpgMaxPercentage.equals(that.rpgMaxPercentage) : that.rpgMaxPercentage != null) return false;
        if (retObligatoryRefNumber != null ? !retObligatoryRefNumber.equals(that.retObligatoryRefNumber) : that.retObligatoryRefNumber != null) return false;
        if (hasDetail != null ? !hasDetail.equals(that.hasDetail) : that.hasDetail != null) return false;
        if (externalReference != null ? !externalReference.equals(that.externalReference) : that.externalReference != null) return false;
        if (deferredDate != null ? !deferredDate.equals(that.deferredDate) : that.deferredDate != null) return false;
        if (subtype != null ? !subtype.equals(that.subtype) : that.subtype != null) return false;
        if (reference != null ? !reference.equals(that.reference) : that.reference != null) return false;
        if (viewSuc != null ? !viewSuc.equals(that.viewSuc) : that.viewSuc != null) return false;
        if (reqIssueDate != null ? !reqIssueDate.equals(that.reqIssueDate) : that.reqIssueDate != null) return false;
        if (reqCurrencyRate != null ? !reqCurrencyRate.equals(that.reqCurrencyRate) : that.reqCurrencyRate != null) return false;
        if (reqIssuerBank != null ? !reqIssuerBank.equals(that.reqIssuerBank) : that.reqIssuerBank != null) return false;
        return optionCodes != null ? optionCodes.equals(that.optionCodes) : that.optionCodes == null;
    }

    @Override
    public int hashCode() {
        int result = id != null ? id.hashCode() : 0;
        result = 31 * result + (owner != null ? owner.hashCode() : 0);
        result = 31 * result + (type != null ? type.hashCode() : 0);
        result = 31 * result + (name != null ? name.hashCode() : 0);
        result = 31 * result + (description != null ? description.hashCode() : 0);
        result = 31 * result + (visible != null ? visible.hashCode() : 0);
        result = 31 * result + (enable != null ? enable.hashCode() : 0);
        result = 31 * result + (obligatoryComment != null ? obligatoryComment.hashCode() : 0);
        result = 31 * result + (dedRetMessage != null ? dedRetMessage.hashCode() : 0);
        result = 31 * result + (intCode != null ? intCode.hashCode() : 0);
        result = 31 * result + (rpgMaxPercentage != null ? rpgMaxPercentage.hashCode() : 0);
        result = 31 * result + (retObligatoryRefNumber != null ? retObligatoryRefNumber.hashCode() : 0);
        result = 31 * result + (hasDetail != null ? hasDetail.hashCode() : 0);
        result = 31 * result + (externalReference != null ? externalReference.hashCode() : 0);
        result = 31 * result + (deferredDate != null ? deferredDate.hashCode() : 0);
        result = 31 * result + (subtype != null ? subtype.hashCode() : 0);
        result = 31 * result + (reference != null ? reference.hashCode() : 0);
        result = 31 * result + (viewSuc != null ? viewSuc.hashCode() : 0);
        result = 31 * result + (reqIssueDate != null ? reqIssueDate.hashCode() : 0);
        result = 31 * result + (reqCurrencyRate != null ? reqCurrencyRate.hashCode() : 0);
        result = 31 * result + (reqIssuerBank != null ? reqIssuerBank.hashCode() : 0);
        result = 31 * result + (optionCodes != null ? optionCodes.hashCode() : 0);
        return result;
    }
}

==> sdd.ebfapi.client-0.4.1.7-sources.jar: ar/com/sdd/ebfapi/client/model/DocumentReasonTypeEbfApi.java <==
package ar.com.sdd.ebfapi.client.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import java.io.Serializable;
import java.math.BigDecimal;

@JsonIgnoreProperties(ignoreUnknown = true)
public class DocumentReasonTypeEbfApi implements Serializable {

    private String id;
    private String ownerUid;
    private String type;
    private String name;
    private String description;
    private Boolean visible;
    private Boolean enable;
    private Boolean obligatoryComment;
    private String dedRetMessage;
    private Long intCode;
    private BigDecimal rpgMaxPercentage;
    private Boolean retObligatoryRefNumber;
    private String hasDetail;
    private String externalReference;
    private Boolean deferredDate;
    private String subtype;
    private String reference;
    private Boolean viewSuc;
    private Boolean reqIssueDate;
    private Boolean reqCurrencyRate;
    private Boolean reqIssuerBank;
    private String optionCodes;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOwnerUid() {
        return ownerUid;
    }

    public void setOwnerUid(String ownerUid) {
        this.ownerUid = ownerUid;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Boolean getVisible() {
        return visible;
    }

    public void setVisible(Boolean visible) {
        this.visible = visible;
    }

    public Boolean getEnable() {
        return enable;
    }

    public void setEnable(Boolean enable) {
        this.enable = enable;
    }

    public Boolean getObligatoryComment() {
        return obligatoryComment;
    }

    public void setObligatoryComment(Boolean obligatoryComment) {
        this.obligatoryComment = obligatoryComment;
    }

    public String getDedRetMessage() {
        return dedRetMessage;
    }

    public void setDedRetMessage(String dedRetMessage) {
        this.dedRetMessage = dedRetMessage;
    }

    public Long getIntCode() {
        return intCode;
    }

    public void setIntCode(Long intCode) {
        this.intCode = intCode;
    }

    public BigDecimal getRpgMaxPercentage() {
        return rpgMaxPercentage;
    }

    public void setRpgMaxPercentage(BigDecimal rpgMaxPercentage) {
        this.rpgMaxPercentage = rpgMaxPercentage;
    }

    public Boolean getRetObligatoryRefNumber() {
        return retObligatoryRefNumber;
    }

    public void setRetObligatoryRefNumber(Boolean retObligatoryRefNumber) {
        this.retObligatoryRefNumber = retObligatoryRefNumber;
    }

    public String getHasDetail() {
        return hasDetail;
    }

    public void setHasDetail(String hasDetail) {
        this.hasDetail = hasDetail;
    }

    public String getExternalReference() {
        return externalReference;
    }

    public void setExternalReference(String externalReference) {
        this.externalReference = externalReference;
    }

    public Boolean getDeferredDate() {
        return deferredDate;
    }

    public void setDeferredDate(Boolean deferredDate) {
        this.deferredDate = deferredDate;
    }

    public String getSubtype() {
        return subtype;
    }

    public void setSubtype(String subtype) {
        this.subtype = subtype;
    }

    public String getReference() {
        return reference;
    }

    public void setReference(String reference) {
        this.reference = reference;
    }

    public Boolean getViewSuc() {
        return viewSuc;
    }

    public void setViewSuc(Boolean viewSuc) {
        this.viewSuc = viewSuc;
    }

    public Boolean getReqIssueDate() {
        return reqIssueDate;
    }

    public void setReqIssueDate(Boolean reqIssueDate) {
        this.reqIssueDate = reqIssueDate;
    }

    public Boolean getReqCurrencyRate() {
        return reqCurrencyRate;
    }

    public void setReqCurrencyRate(Boolean reqCurrencyRate) {
        this.reqCurrencyRate = reqCurrencyRate;
    }

    public Boolean getReqIssuerBank() {
        return reqIssuerBank;
    }

    public void setReqIssuerBank(Boolean reqIssuerBank) {
        this.reqIssuerBank = reqIssuerBank;
    }

    public String getOptionCodes() {
        return optionCodes;
    }

    public void setOptionCodes(String optionCodes) {
        this.optionCodes = optionCodes;
    }

    @Override
    public String toString() {
        return "DocumentReasonTypeEbfApi ["
                + ((id != null) ? "id=" + id + ", " : "")
                + ((ownerUid != null) ? "ownerUid=" + ownerUid + ", " : "")
                + ((type != null) ? "type=" + type + ", " : "")
                + ((name != null) ? "name=" + name + ", " : "")
                + ((description != null) ? "description=" + description + ", " : "")
                + ((visible != null) ? "visible=" + visible + ", " : "")
                + ((enable != null) ? "enable=" + enable + ", " : "")
                + ((obligatoryComment != null) ? "obligatoryComment=" + obligatoryComment + ", " : "")
                + ((dedRetMessage != null) ? "dedRetMessage=" + dedRetMessage + ", " : "")
                + ((intCode != null) ? "intCode=" + intCode + ", " : "")
                + ((rpgMaxPercentage != null) ? "rpgMaxPercentage=" + rpgMaxPercentage + ", " : "")
                + ((retObligatoryRefNumber != null) ? "retObligatoryRefNumber=" + retObligatoryRefNumber + ", " : "")
                + ((hasDetail != null) ? "hasDetail=" + hasDetail + ", " : "")
                + ((externalReference != null) ? "externalReference=" + externalReference + ", " : "")
                + ((deferredDate != null) ? "deferredDate=" + deferredDate + ", " : "")
                + ((subtype != null) ? "subtype=" + subtype + ", " : "")
                + ((reference != null) ? "reference=" + reference + ", " : "")
                + ((viewSuc != null) ? "viewSuc=" + viewSuc + ", " : "")
                + ((reqIssueDate != null) ? "reqIssueDate=" + reqIssueDate + ", " : "")
                + ((reqCurrencyRate != null) ? "reqCurrencyRate=" + reqCurrencyRate + ", " : "")
                + ((reqIssuerBank != null) ? "reqIssuerBank=" + reqIssuerBank + ", " : "")
                + ((optionCodes != null) ? "optionCodes=" + optionCodes : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        DocumentReasonTypeEbfApi that = (DocumentReasonTypeEbfApi) o;

        if (id != null ? !id.equals(that.id) : that.id != null) return false;
        if (ownerUid != null ? !ownerUid.equals(that.ownerUid) : that.ownerUid != null) return false;
        if (type != null ? !type.equals(that.type) : that.type != null) return false;
        if (name != null ? !name.equals(that.name) : that.name != null) return false;
        if (description != null ? !description.equals(that.description) : that.description != null) return false;
        if (visible != null ? !visible.equals(that.visible) : that.visible != null) return false;
        if (enable != null ? !enable.equals(that.enable) : that.enable != null) return false;
        if (obligatoryComment != null ? !obligatoryComment.equals(that.obligatoryComment) : that.obligatoryComment != null) return false;
        if (dedRetMessage != null ? !dedRetMessage.equals(that.dedRetMessage) : that.dedRetMessage != null) return false;
        if (intCode != null ? !intCode.equals(that.intCode) : that.intCode != null) return false;
        if (rpgMaxPercentage != null ? !rpgMaxPercentage.equals(that.rpgMaxPercentage) : that.rpgMaxPercentage != null) return false;
        if (retObligatoryRefNumber != null ? !retObligatoryRefNumber.equals(that.retObligatoryRefNumber) : that.retObligatoryRefNumber != null) return false;
        if (hasDetail != null ? !hasDetail.equals(that.hasDetail) : that.hasDetail != null) return false;
        if (externalReference != null ? !externalReference.equals(that.externalReference) : that.externalReference != null) return false;
        if (deferredDate != null ? !deferredDate.equals(that.deferredDate) : that.deferredDate != null) return false;
        if (subtype != null ? !subtype.equals(that.subtype) : that.subtype != null) return false;
        if (reference != null ? !reference.equals(that.reference) : that.reference != null) return false;
        if (viewSuc != null ? !viewSuc.equals(that.viewSuc) : that.viewSuc != null) return false;
        if (reqIssueDate != null ? !reqIssueDate.equals(that.reqIssueDate) : that.reqIssueDate != null) return false;
        if (reqCurrencyRate != null ? !reqCurrencyRate.equals(that.reqCurrencyRate) : that.reqCurrencyRate != null) return false;
        if (reqIssuerBank != null ? !reqIssuerBank.equals(that.reqIssuerBank) : that.reqIssuerBank != null) return false;
        return optionCodes != null ? optionCodes.equals(that.optionCodes) : that.optionCodes == null;
    }

    @Override
    public int hashCode() {
        int result = id != null ? id.hashCode() : 0;
        result = 31 * result + (ownerUid != null ? ownerUid.hashCode() : 0);
        result = 31 * result + (type != null ? type.hashCode() : 0);
        result = 31 * result + (name != null ? name.hashCode() : 0);
        result = 31 * result + (description != null ? description.hashCode() : 0);
        result = 31 * result + (visible != null ? visible.hashCode() : 0);
        result = 31 * result + (enable != null ? enable.hashCode() : 0);
        result = 31 * result + (obligatoryComment != null ? obligatoryComment.hashCode() : 0);
        result = 31 * result + (dedRetMessage != null ? dedRetMessage.hashCode() : 0);
        result = 31 * result + (intCode != null ? intCode.hashCode() : 0);
        result = 31 * result + (rpgMaxPercentage != null ? rpgMaxPercentage.hashCode() : 0);
        result = 31 * result + (retObligatoryRefNumber != null ? retObligatoryRefNumber.hashCode() : 0);
        result = 31 * result + (hasDetail != null ? hasDetail.hashCode() : 0);
        result = 31 * result + (externalReference != null ? externalReference.hashCode() : 0);
        result = 31 * result + (deferredDate != null ? deferredDate.hashCode() : 0);
        result = 31 * result + (subtype != null ? subtype.hashCode() : 0);
        result = 31 * result + (reference != null ? reference.hashCode() : 0);
        result = 31 * result + (viewSuc != null ? viewSuc.hashCode() : 0);
        result = 31 * result + (reqIssueDate != null ? reqIssueDate.hashCode() : 0);
        result = 31 * result + (reqCurrencyRate != null ? reqCurrencyRate.hashCode() : 0);
        result = 31 * result + (reqIssuerBank != null ? reqIssuerBank.hashCode() : 0);
        result = 31 * result + (optionCodes != null ? optionCodes.hashCode() : 0);
        return result;
    }
}
